aboutsummaryrefslogtreecommitdiff
path: root/src/backend/access/common/scankey.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/access/common/scankey.c')
-rw-r--r--src/backend/access/common/scankey.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/backend/access/common/scankey.c b/src/backend/access/common/scankey.c
index 781516c56a5..5be4fe85eb1 100644
--- a/src/backend/access/common/scankey.c
+++ b/src/backend/access/common/scankey.c
@@ -64,9 +64,9 @@ ScanKeyEntryInitialize(ScanKey entry,
* It cannot handle NULL arguments, unary operators, or nondefault operators,
* but we need none of those features for most hardwired lookups.
*
* We set collation to DEFAULT_COLLATION_OID always. This is appropriate
* for textual columns in system catalogs, and it will be ignored for
* non-textual columns, so it's not worth trying to be more finicky.
*
* Note: CurrentMemoryContext at call should be as long-lived as the ScanKey
* itself, because that's what will be used for any subsidiary info attached
@@ -83,7 +83,7 @@ ScanKeyInit(ScanKey entry,
entry->sk_attno = attributeNumber;
entry->sk_strategy = strategy;
entry->sk_subtype = InvalidOid;
- entry->sk_collation = DEFAULT_COLLATION_OID;
+ entry->sk_collation = C_COLLATION_OID;
entry->sk_argument = argument;
fmgr_info(procedure, &entry->sk_func);
}
@@ -64,9 +64,9 @@ ScanKeyEntryInitialize(ScanKey entry,
* but we need none of those features for most hardwired lookups.
*
- * We set collation to DEFAULT_COLLATION_OID always. This is appropriate
- * for textual columns in system catalogs, and it will be ignored for
- * non-textual columns, so it's not worth trying to be more finicky.
+ * We set collation to C_COLLATION_OID always. This is the correct value
+ * for all collation-aware columns in system catalogs, and it will be ignored
+ * for other column types, so it's not worth trying to be more finicky.
*
* Note: CurrentMemoryContext at call should be as long-lived as the ScanKey